@@ -3,6 +3,12 @@ from ..functions import log as log_provider
 
 
 def log(index: str, doc, params=None, headers=None):
+
+    def pass_func():
+        pass
+
+    return pass_func
+
     def decorator(func):
         @wraps(func)
         def inner(*args, **kwargs):
